@@ -1,4 +1,4 @@
-g.analyse.perfile = function(ID, ID2, IDd, fname, deviceSerialNumber, BodyLocation, startt, I, LC2, LD, dcomplscore,
+g.analyse.perfile = function(ID, fname, deviceSerialNumber, BodyLocation, startt, I, LC2, LD, dcomplscore,
                              LMp, LWp, C, lookat, AveAccAve24hr, colnames_to_lookat, QUAN, ML5AD,
                              ML5AD_names, igfullr, igfullr_names,
                              daysummary, ds_names, includedaycrit, strategy, hrs.del.start,
@@ -9,17 +9,7 @@ g.analyse.perfile = function(ID, ID2, IDd, fname, deviceSerialNumber, BodyLocati
   s_names = rep(" ",ncol(filesummary))
   vi = 1
   # Person identification number
-  if (idloc == 2) {
-    filesummary[vi] = unlist(strsplit(fname,"_"))[1] #id
-  } else if (idloc == 4) {
-    filesummary[vi] = IDd
-  } else if (idloc == 1) {
-    filesummary[vi] = ID
-  } else if (idloc == 3) {
-    filesummary[vi] = ID2
-  } else if (idloc == 5) {
-    filesummary[vi] = unlist(strsplit(fname," "))[1] #id
-  }
+  filesummary[vi] = ID
   # Serial number
   if (snloc == 1) {
     filesummary[(vi+1)] = deviceSerialNumber
