@@ -54,7 +54,8 @@ g.dotorcomma = function(inputfile,dformat,mon, desiredtz = "", ...) {
     try(expr={deci = g.wavread(wavfile=inputfile,start=1,end=10)},silent=TRUE)
     if(is.na(suppressWarnings(as.numeric(deci$rawxyz[2,2]))) == T & getOption("OutDec") == ".") decn = ","
   } else if (dformat == 4) {
-    try(expr={deci = g.cwaread(inputfile,start = 1, end = 10, desiredtz = desiredtz)$data},silent=TRUE)
+    try(expr={deci = g.cwaread(fileName = inputfile,start = 1, end = 10, desiredtz = desiredtz,
+                               interpolationType=1)$data},silent=TRUE)
     if(is.na(suppressWarnings(as.numeric(deci[2,2]))) == T & getOption("OutDec") == ".") decn = ","
   }
   dotorcomma = decn
