@@ -5,7 +5,7 @@ test_that("Part 1 can run with all metrics", {
   #=======================
   # Part 1 with all metrics
   Ndays = 2
-  create_test_acc_csv(Nmin=Ndays*1440)
+  create_test_acc_csv(Nmin=Ndays*1440, sf = 9) # 9 Hertz,  because metric zc filters at 4 Hertz
   create_test_sleeplog_csv()
   fn = "123A_testaccfile.csv"
   sleeplog_fn = "testsleeplogfile.csv"
@@ -19,17 +19,18 @@ test_that("Part 1 can run with all metrics", {
           do.enmo = TRUE,do.lfenmo = TRUE,
           do.bfen = TRUE,
           do.hfenplus = TRUE,
-          do.mad = TRUE, do.sgAccEN=FALSE,
+          do.mad = TRUE, do.sgAccEN=FALSE,do.zcx=TRUE,
    windowsizes = c(15,3600,3600), do.parallel=FALSE,
    minimumFileSizeMB=0)
   rn = dir("output_test/meta/basic/",full.names = TRUE)
   load(rn[1])
-  expect_that(ncol(M$metashort),equals(6))
+  expect_that(ncol(M$metashort),equals(7))
   expect_that(nrow(M$metashort),equals(11280))
-  expect_that(round(mean(M$metashort$BFEN),digits=4),equals(0.0302))
+  expect_that(round(mean(M$metashort$BFEN),digits=4),equals(0.0413))
   expect_that(round(mean(M$metashort$LFENMO),digits=4),equals(0.0442))
-  expect_that(round(mean(M$metashort$HFENplus),digits=4),equals(0.0804))
-  expect_that(round(mean(M$metashort$MAD),digits=4),equals(0.0072))
+  expect_that(round(mean(M$metashort$HFENplus),digits=4),equals(0.0904))
+  expect_that(round(mean(M$metashort$MAD),digits=4),equals(0.0073))
+  expect_that(round(mean(M$metashort$ZCX),digits=4),equals(17.4165))
    
   if (file.exists(fn)) file.remove(fn)
   if (file.exists(sleeplog_fn)) file.remove(sleeplog_fn)
